import unittest
from zope.testing import doctest

optionflags =  (doctest.ELLIPSIS |
                doctest.NORMALIZE_WHITESPACE |
                doctest.REPORT_ONLY_FIRST_FAILURE)

def test_suite():
    suite = unittest.TestSuite((
            doctest.DocFileSuite(
                'README.txt',
                optionflags=optionflags,
                ),
            ))
    return suite

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')



"""Decorators useful with Zope browser views."""

import simplejson

def json(func=None, **decorator_kwargs):
    """Simple JSON decorator that generates a JSON formatted string of the
    output of the decorated function.
    """
    if func is not None:
        # We got a function, return a decorated version of it
        def json_decor(*args, **kwargs):
            return simplejson.dumps(func(*args, **kwargs), **decorator_kwargs)

        json_decor.__doc__ = func.__doc__
        json_decor.__dict__ = func.__dict__
        json_decor.__module__ = func.__module__
        json_decor.__name__ = func.__name__
        return json_decor

    else:
        # We got simplejson arguments, so we need to return a new
        # decorator function. We simply use a recursive call.
        return lambda f: json(f, **decorator_kwargs)


def nocache(func):
    """Decorator that disables HTTP caching by setting the appropriate
    cache headers."""
    def disable_cache(self, *args, **kwargs):
        self.request.response.setHeader('Pragma', 'no-cache')
        self.request.response.setHeader('Expires', 'Sat, 1 Jan 2000 00:00:00 GMT')
        self.request.response.setHeader('Cache-Control', 'no-cache, must-revalidate')
        return func(self, *args, **kwargs)
    disable_cache.__doc__ = func.__doc__
    disable_cache.__dict__ = func.__dict__
    disable_cache.__module__ = func.__module__
    disable_cache.__name__ = func.__name__
    return disable_cache



from setuptools import setup, find_packages
import sys, os

version = '0.1'
name = 'hexagonit.decorators'

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(name=name,
      version=version,
      description="Collection of useful decorators for Zope development",
      long_description= (
        read('README.txt')
        + '\n' +
        read('CHANGES.txt')
        + '\n' +
        'Detailed Documentation\n'
        '**********************\n'
        + '\n' +
        read('src','hexagonit','decorators','README.txt')
        + '\n' +
        'Download\n'
        '***********************\n'
        ),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Framework :: Zope2',
        'Framework :: Zope3',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        ],
      keywords='',
      author='Kai Lautaportti',
      author_email='kai.lautaportti@hexagonit.fi',
      url='http://pypi.python.org/pypi/%s' % name,
      license='GPL',
      packages=find_packages('src'),
      package_dir={'':'src'},
      namespace_packages=['hexagonit'],
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          'setuptools',
          'simplejson'
      ],
      tests_require = ['zope.testing'],
      test_suite = '%s.tests.test_suite' % name,
      )
